@@ -41,6 +41,22 @@ def default_if_empty(v, default):
 
 
 @register.simple_tag(takes_context=True)
-def bind(context, button):
-    button.bind(context)
-    return button
+def get_action_buttons(context, model_admin):
+    return [button.bind(context) for button in model_admin.get_action_buttons(context['request'])]
+
+
+@register.simple_tag(takes_context=True)
+def get_changeform_buttons(context, model_admin):
+    original = context['original']
+    return [button.bind(context) for button in model_admin.get_changeform_buttons(context['request'], original)]
+
+
+@register.simple_tag(takes_context=True)
+def get_changelist_buttons(context, model_admin):
+    return [button.bind(context) for button in model_admin.get_changelist_buttons(context['request'])]
+
+#
+# @register.simple_tag(takes_context=True)
+# def bind(context, button):
+#     button.bind(context)
+#     return button
